%global         forgeurl        https://github.com/praat/praat
Version:        6.3.17
%global         tag             v%{version}
%forgemeta

Name:           praat
Release:        1%{?dist}
Summary:        Doing phoenetics by computer

License:        GPL-3.0-or-later
URL:            https://www.praat.org
Source0:        %{fogreurl}/archive/v%{version}/praat-%{version}.tar.gz
# https://www.fon.hum.uva.nl/praat/manual/General_Public_License__version_3.html
Source1:        LICENSE.txt
# https://www.fon.hum.uva.nl/praat/praat.png
Source2:        praat.png
Source3:        praat.desktop
# Modify paths and compilation options for Fedora build
Patch:          fedora-setup.patch

BuildRequires:  alsa-lib-devel
BuildRequires:  jack-audio-connection-kit-devel
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gtk3-devel
BuildRequires:  make
BuildRequires:  pulseaudio-libs-devel
BuildRequires:  desktop-file-utils
# Bundled dependencies
Provides:  bundled(clapack)
Provides:  bundled(espeak-ng)
Provides:  bundled(flac)
Provides:  bundled(glpk)
Provides:  bundled(gsl)
Provides:  bundled(libvorbis)
Provides:  bundled(opusfile)
Provides:  bundled(portaudio)

%global _description %{expand:
Welcome to Praat! Praat is a speech analysis tool used for
doing phonetics by computer.  Praat can analyse, synthesize,
and manipulate speech, and create high-quality pictures
for your publications. Praat was created by Paul Boersma and
David Weenink of the Institute of Phonetics Sciences of the
University of Amsterdam.

Some of Praat’s most prominent features are:

SPEECH ANALYSIS

Praat allows you to analyze different aspects of speech including
pitch, formant, intensity, and voice quality. You have access to
spectrograms (a visual representation of sound changing over time)
and cochleagrams (a specific type of spectrogram more closely
resembling how the inner ear receives sound).

SPEECH SYNTHESIS

Praat allows you to generate speech from a pitch curve and filters
that you create (acoustic synthesis), or from muscle activities
(articulatory synthesis).

SPEECH MANIPULATION

Praat gives you the ability to modify existing speech utterances. You
can alter pitch, intensity, and duration of speech.

SPEECH LABELLING

Praat allows you to custom-label your samples using the IPA
(International Phonetics Alphabet), and annotate your sound
segments based on the particular variables you are seeking
to analyze.  Multi-language text-to-speech facilities allow
you to segment the sound into words and phonemes.

GRAMMAR MODELS

With Praat, you can try out Optimality-Theoretic and Harmonic-Grammar
learning, as well as several kinds of neural-network models.

STATISTICAL ANALYSIS

Praat allows you to perform several statistical techniques, among which
multidimensional scaling, principal component analysis, and discriminant
analysis.

For more information, consult the website praat.org, which has Praat
tutorials in several languages.}

%description %_description


%prep
%autosetup -p1 -n praat-%{version}
cp %{SOURCE1} .
cp %{SOURCE2} .
cp makefiles/makefile.defs.linux.pulse makefile.defs 

%build
%make_build

%install
mkdir -p %{buildroot}/%{_bindir}/
mkdir -p %{buildroot}/%{_datadir}/pixmaps/
install -Dm755 praat %{buildroot}/%{_bindir}/praat
install -Dm644 praat.png %{buildroot}/%{_datadir}/pixmaps/praat.png

desktop-file-install                                    \
--dir=%{buildroot}%{_datadir}/applications              \
%{SOURCE3}
desktop-file-validate %{buildroot}/%{_datadir}/applications/praat.desktop

%check
# smoke test
%{buildroot}/%{_bindir}/praat --help

%files
%license LICENSE.txt
%doc README.md
%{_bindir}/praat
%{_datadir}/applications/praat.desktop
%{_datadir}/pixmaps/praat.png

%changelog
* Wed Sep 13 2023 Benson Muite <benson_muite@emailplus.org> - 6.3.17-1
- Initial package
